html, body {
    width: 100%;
    height: 100%;
    margin: 0px;
    border: 0;
    overflow: hidden;
    display: block;
    background-color: #2e3436;
}

canvas {
    left: 0px;
    top: 0px;
    background-color: #2e3436;
}

div {
    display: flex;
    justify-content: center;
}

input {
    border: none;
    border-radius: 4px;
    background-color: #eeeeec;
    color: #2e3436;
    font-size: 1.25em;
    padding: 0.3em;
    margin: 0.2em 0.1em;
}

input[type=text] {
    width: 50vw;
}
